#!/usr/bin/env python3
import utils
import json
import random
import string


class JsonConfig:
    def __init__(self, path):
        self.path = path
        with open(path, 'r') as f:
            self.conf = json.load(f)

    def write(self):
        with open(self.path, 'w') as f:
            json.dump(self.conf, f, indent=2, sort_keys=True)

    def set(self, key, val):
        self.conf[key] = val

    def get(self):
        return self.conf


def get_random_id(length=12):
    return ''.join(random.SystemRandom().choice(string.ascii_letters + string.digits) for _ in range(length))


def write_netcapture_conf():
    conf = JsonConfig('/etc/miris/netcapture.json.example')
    conf.set('docker_registry_login', utils.get_conf('NETCAPTURE_DOCKER_LOGIN', ''))
    conf.set('docker_registry_password', utils.get_conf('NETCAPTURE_DOCKER_PWD', ''))
    conf.set('campusmanager_url', 'https://%s' % utils.get_conf('CM_SERVER_NAME', ''))
    conf.write()
    return conf.get()


def write_miris_conf():
    conf = JsonConfig('/etc/miris/conf/api.json')
    conf.set('auth_user_password', get_random_id())
    conf.write()


def setup(interactive=True):
    # Run commands
    cmds = [
        'apt-get install --yes apt-transport-https ca-certificates curl software-properties-common',
        'curl -fsSL https://download.docker.com/linux/ubuntu/gpg | apt-key add -',
        'add-apt-repository "deb [arch=amd64] https://download.docker.com/linux/ubuntu $(lsb_release -cs) stable"',
        'apt-get update && apt-get install --yes docker-ce',
        'apt-get install --yes python3-miris-netcapture',
    ]

    try:
        utils.run_commands(cmds)
        conf = write_netcapture_conf()
        write_miris_conf()
        cmds_post = list()
        for f in ['media', 'conf']:
            cmds_post.extend([
                'mkdir -p %s' % conf['netcapture_%s_folder' % f],
                'chgrp -R video %s' % conf['netcapture_%s_folder' % f],
                'chmod -R 774 %s' % conf['netcapture_%s_folder' % f],
            ])
        utils.run_commands(cmds_post)
    except Exception:
        raise
